| Title: | Convert Video Files to 'mp3' Format, Merge or Trim Audio Files using 'FFmpeg' |
|---|---|
| Description: | Converts video files to 'mp3', merges multiple audio files and trims audio files using 'FFmpeg', which is dynamically downloaded to avoid bundling any third-party binaries. Users must ensure compliance with the license terms of 'FFmpeg' when using the package. See <https://github.com/BtbN/FFmpeg-Builds/releases/download/latest/ffmpeg-master-latest-win64-gpl.zip> for details. |
| Authors: | Lijin Arakkandathil Thekkathil [aut, cre] |
| Maintainer: | Lijin Arakkandathil Thekkathil <[email protected]> |
| License: | GPL-3 |
| Version: | 1.0.7 |
| Built: | 2026-06-08 08:29:09 UTC |
| Source: | https://github.com/lijin-5673/ljmp3converter |
This function downloads the latest 'FFmpeg' executable and sets it up for the user. It ensures compliance with MIT licensing by not bundling 'FFmpeg' within the package.
download_ffmpeg()download_ffmpeg()
A string containing the path to the downloaded 'FFmpeg' executable.
This function merges multiple audio files (MP3, WAV, AAC, FLAC, OGG, M4A) into a single MP3 file using FFmpeg.
merge_mp3()merge_mp3()
No return value, called for side effects.
## Not run: if (interactive()) { merge_mp3() } ## End(Not run)## Not run: if (interactive()) { merge_mp3() } ## End(Not run)
This function converts video files to MP3. It provides a simple interface for selecting an input folder and processing the files, with the converted MP3 files saved in the same input folder.
run_converter_app()run_converter_app()
No return value, called for side effects.
## Not run: if (interactive()) { run_converter_app() } ## End(Not run)## Not run: if (interactive()) { run_converter_app() } ## End(Not run)
This function trims an audio file based on user-provided start and end times using FFmpeg.
trim_audio()trim_audio()
No return value, called for side effects.
## Not run: if (interactive()) { trim_audio() } ## End(Not run)## Not run: if (interactive()) { trim_audio() } ## End(Not run)